#ifndef F_CPU
#define F_CPU 16000000UL
#endif

#include <avr/io.h>
#include <util/delay.h>
#include <stdlib.h>

#include "i2c_master.h"

#define PCF8574_WRITE 0x4E
#define PCF8574_READ  0x4F

void init_uart(uint16_t baudrate){

	uint16_t UBRR_val = (F_CPU/16)/(baudrate-1);

	UBRR0H = UBRR_val >> 8;
	UBRR0L = UBRR_val;

	UCSR0B |= (1<<TXEN0) | (1<<RXEN0) | (1<<RXCIE0); // UART TX (Transmit - senden) einschalten
	UCSR0C |= (1<<USBS0) | (3<<UCSZ00); // Modus Asynchron 8N1 (8 Datenbits, No Parity, 1 Stopbit)
}

void uart_putc(unsigned char c){

	while(!(UCSR0A & (1<<UDRE0))); // wait until sending is possible
	UDR0 = c; // output character saved in c
}

void uart_puts(char *s){
	while(*s){
		uart_putc(*s);
		s++;
	}
}

char buffer[6];


int main(void){

	init_uart(9600);
	i2c_init();

	uart_puts("Started\n");

	while(1){
		uart_puts("Toggling...\n");

		i2c_start(PCF8574_WRITE);
		i2c_write(0x00);
		i2c_stop();

		_delay_ms(1000);

		uart_puts("Toggling...\n");
		i2c_start(PCF8574_WRITE);
		i2c_write(0xff);
		i2c_stop();

		_delay_ms(1000);
	}

	return 0;
}
